pub struct Node {
pub id: u64,
pub rank: u64,
pub connected_with: HashSet<u64>,
}Expand description
A Node represents single concept and its connections to other concepts.
Each node can have multiple edges to other nodes
Fields
id: u64Unique identifier of the node (u64)
rank: u64Number of co-occurrences
connected_with: HashSet<u64>List of connected edges
Implementations